@@ -20,7 +20,9 @@
 #ifndef RECORDING_H
 #define RECORDING_H
 
-#include <akelement.h>
+#include <akcaps.h>
+#include <akpropertyoption.h>
+#include <iak/akelement.h>
 
 class RecordingPrivate;
 class Recording;
@@ -33,6 +35,8 @@ using RecordingPtr = QSharedPointer<Recording>;
 class Recording: public QObject
 {
     Q_OBJECT
+
+    // General options
     Q_PROPERTY(AkAudioCaps audioCaps
                READ audioCaps
                WRITE setAudioCaps
@@ -48,77 +52,36 @@ class Recording: public QObject
                WRITE setState
                RESET resetState
                NOTIFY stateChanged)
+
+    // Video
     Q_PROPERTY(QString videoDirectory
                READ videoDirectory
                WRITE setVideoDirectory
                RESET resetVideoDirectory
                NOTIFY videoDirectoryChanged)
-    Q_PROPERTY(QStringList availableVideoFormats
-               READ availableVideoFormats
-               NOTIFY availableVideoFormatsChanged)
-    Q_PROPERTY(QStringList availableVideoFormatExtensions
-               READ availableVideoFormatExtensions
-               NOTIFY availableVideoFormatExtensionsChanged)
-    Q_PROPERTY(QVariantList availableVideoFormatOptions
-               READ availableVideoFormatOptions
-               NOTIFY availableVideoFormatOptionsChanged)
-    Q_PROPERTY(QStringList availableVideoCodecs
-               READ availableVideoCodecs
-               NOTIFY availableVideoCodecsChanged)
-    Q_PROPERTY(QStringList availableAudioCodecs
-               READ availableAudioCodecs
-               NOTIFY availableAudioCodecsChanged)
-    Q_PROPERTY(QVariantList availableVideoCodecOptions
-               READ availableVideoCodecOptions
-               NOTIFY availableVideoCodecOptionsChanged)
-    Q_PROPERTY(QVariantList availableAudioCodecOptions
-               READ availableAudioCodecOptions
-               NOTIFY availableAudioCodecOptionsChanged)
     Q_PROPERTY(QString videoFormat
                READ videoFormat
                WRITE setVideoFormat
                RESET resetVideoFormat
                NOTIFY videoFormatChanged)
-    Q_PROPERTY(QString videoFormatExtension
-               READ videoFormatExtension
-               WRITE setVideoFormatExtension
-               RESET resetVideoFormatExtension
-               NOTIFY videoFormatExtensionChanged)
-    Q_PROPERTY(QVariantMap videoFormatOptions
+    Q_PROPERTY(QStringList videoFormats
+               READ videoFormats
+               CONSTANT)
+    Q_PROPERTY(QString defaultVideoFormat
+               READ defaultVideoFormat
+               CONSTANT)
+    Q_PROPERTY(AkPropertyOptions videoFormatOptions
                READ videoFormatOptions
-               WRITE setVideoFormatOptions
                RESET resetVideoFormatOptions
                NOTIFY videoFormatOptionsChanged)
-    Q_PROPERTY(QString videoCodec
-               READ videoCodec
-               WRITE setVideoCodec
-               RESET resetVideoCodec
-               NOTIFY videoCodecChanged)
-    Q_PROPERTY(QString audioCodec
-               READ audioCodec
-               WRITE setAudioCodec
-               RESET resetAudioCodec
-               NOTIFY audioCodecChanged)
-    Q_PROPERTY(QVariantMap videoCodecParams
-               READ videoCodecParams
-               WRITE setVideoCodecParams
-               RESET resetVideoCodecParams
-               NOTIFY videoCodecParamsChanged)
-    Q_PROPERTY(QVariantMap audioCodecParams
-               READ audioCodecParams
-               WRITE setAudioCodecParams
-               RESET resetAudioCodecParams
-               NOTIFY audioCodecParamsChanged)
-    Q_PROPERTY(QVariantMap videoCodecOptions
-               READ videoCodecOptions
-               WRITE setVideoCodecOptions
-               RESET resetVideoCodecOptions
-               NOTIFY videoCodecOptionsChanged)
-    Q_PROPERTY(QVariantMap audioCodecOptions
-               READ audioCodecOptions
-               WRITE setAudioCodecOptions
-               RESET resetAudioCodecOptions
-               NOTIFY audioCodecOptionsChanged)
+    Q_PROPERTY(int videoGOP
+               READ videoGOP
+               WRITE setVideoGOP
+               RESET resetVideoGOP
+               NOTIFY videoGOPChanged)
+    Q_PROPERTY(int defaultVideoGOP
+               READ defaultVideoGOP
+               CONSTANT)
     Q_PROPERTY(bool recordAudio
                READ recordAudio
                WRITE setRecordAudio
@@ -130,6 +93,11 @@ class Recording: public QObject
     Q_PROPERTY(QString lastVideo
                READ lastVideo
                NOTIFY lastVideoChanged)
+    Q_PROPERTY(QString latestVideoUri
+               READ latestVideoUri
+               NOTIFY latestVideoUriChanged)
+
+    // Picture
     Q_PROPERTY(QString imagesDirectory
                READ imagesDirectory
                WRITE setImagesDirectory
@@ -146,6 +114,9 @@ class Recording: public QObject
     Q_PROPERTY(QString lastPhotoPreview
                READ lastPhotoPreview
                NOTIFY lastPhotoPreviewChanged)
+    Q_PROPERTY(QString latestPhotoUri
+               READ latestPhotoUri
+               NOTIFY latestPhotoUriChanged)
     Q_PROPERTY(int imageSaveQuality
                READ imageSaveQuality
                WRITE setImageSaveQuality
@@ -164,27 +135,29 @@ class Recording: public QObject
 
         // Video
         Q_INVOKABLE QString videoDirectory() const;
-        Q_INVOKABLE QStringList availableVideoFormats() const;
-        Q_INVOKABLE QStringList availableVideoFormatExtensions() const;
-        Q_INVOKABLE QVariantList availableVideoFormatOptions() const;
-        Q_INVOKABLE QStringList availableVideoCodecs() const;
-        Q_INVOKABLE QStringList availableAudioCodecs() const;
-        Q_INVOKABLE QVariantList availableVideoCodecOptions() const;
-        Q_INVOKABLE QVariantList availableAudioCodecOptions() const;
         Q_INVOKABLE QString videoFormat() const;
-        Q_INVOKABLE QString videoFormatExtension() const;
-        Q_INVOKABLE QVariantMap videoFormatOptions() const;
-        Q_INVOKABLE QString videoCodec() const;
-        Q_INVOKABLE QString audioCodec() const;
-        Q_INVOKABLE QVariantMap videoCodecParams() const;
-        Q_INVOKABLE QVariantMap audioCodecParams() const;
-        Q_INVOKABLE QVariantMap videoCodecOptions() const;
-        Q_INVOKABLE QVariantMap audioCodecOptions() const;
-        Q_INVOKABLE bool recordAudio() const;
-        Q_INVOKABLE QString videoFormatDescription(const QString &formatId) const;
+        Q_INVOKABLE QStringList videoFormats() const;
+        Q_INVOKABLE QString defaultVideoFormat() const;
+        Q_INVOKABLE QString formatDescription(const QString &format) const;
+        Q_INVOKABLE QString codec(AkCaps::CapsType type) const;
+        Q_INVOKABLE QString defaultCodec(const QString &format,
+                                         AkCaps::CapsType type) const;
+        Q_INVOKABLE QStringList supportedCodecs(const QString &format,
+                                                AkCaps::CapsType type) const;
         Q_INVOKABLE QString codecDescription(const QString &codec) const;
+        Q_INVOKABLE AkPropertyOptions videoFormatOptions() const;
+        Q_INVOKABLE QVariant videoFormatOptionValue(const QString &option) const;
+        Q_INVOKABLE AkPropertyOptions codecOptions(AkCaps::CapsType type) const;
+        Q_INVOKABLE QVariant codecOptionValue(AkCaps::CapsType type,
+                                              const QString &option) const;
+        Q_INVOKABLE int bitrate(AkCaps::CapsType type) const;
+        Q_INVOKABLE int defaultBitrate(AkCaps::CapsType type) const;
+        Q_INVOKABLE int videoGOP() const;
+        Q_INVOKABLE int defaultVideoGOP() const;
+        Q_INVOKABLE bool recordAudio() const;
         Q_INVOKABLE QString lastVideoPreview() const;
         Q_INVOKABLE QString lastVideo() const;
+        Q_INVOKABLE QString latestVideoUri() const;
 
         // Picture
         Q_INVOKABLE QString imagesDirectory() const;
@@ -192,78 +165,95 @@ class Recording: public QObject
         Q_INVOKABLE QString imageFormat() const;
         Q_INVOKABLE QString imageFormatDescription(const QString &videoFormat) const;
         Q_INVOKABLE QString lastPhotoPreview() const;
+        Q_INVOKABLE QString latestPhotoUri() const;
         Q_INVOKABLE int imageSaveQuality() const;
 
     private:
         RecordingPrivate *d;
 
     signals:
+        // General options
         void audioCapsChanged(const AkAudioCaps &audioCaps);
         void videoCapsChanged(const AkVideoCaps &videoCaps);
         void stateChanged(AkElement::ElementState state);
+
+        // Video
         void videoDirectoryChanged(const QString &videoDirectory);
-        void availableVideoFormatsChanged(const QStringList &availableVideoFormats);
-        void availableVideoFormatExtensionsChanged(const QStringList &availableVideoFormatExtensions);
-        void availableVideoFormatOptionsChanged(const QVariantList &availableVideoFormatOptions);
-        void availableVideoCodecsChanged(const QStringList &availableVideoCodecs);
-        void availableAudioCodecsChanged(const QStringList &availableAudioCodecs);
-        void availableVideoCodecOptionsChanged(const QVariantList &availableVideoCodecOptions);
-        void availableAudioCodecOptionsChanged(const QVariantList &availableAudioCodecOptions);
         void videoFormatChanged(const QString &videoFormat);
-        void videoFormatExtensionChanged(const QString &videoFormatExtension);
-        void videoFormatOptionsChanged(const QVariantMap &videoFormatOptions);
-        void videoCodecChanged(const QString &videoCodec);
-        void audioCodecChanged(const QString &audioCodec);
-        void videoCodecParamsChanged(const QVariantMap &videoCodecParams);
-        void audioCodecParamsChanged(const QVariantMap &audioCodecParams);
-        void videoCodecOptionsChanged(const QVariantMap &videoCodecOptions);
-        void audioCodecOptionsChanged(const QVariantMap &audioCodecOptions);
+        void codecChanged(AkCaps::CapsType type,
+                          const QString &codec);
+        void videoFormatOptionsChanged(const AkPropertyOptions &options);
+        void videoFormatOptionValueChanged(const QString &option,
+                                           const QVariant &value);
+        void codecOptionsChanged(AkCaps::CapsType type,
+                                 const AkPropertyOptions &options);
+        void codecOptionValueChanged(AkCaps::CapsType type,
+                                     const QString &option,
+                                     const QVariant &value);
+        void bitrateChanged(AkCaps::CapsType type, int bitrate);
+        void videoGOPChanged(int gop);
         void recordAudioChanged(bool recordAudio);
         void lastVideoPreviewChanged(const QString &lastVideoPreview);
         void lastVideoChanged(const QString &lastVideo);
+        void latestVideoUriChanged(const QString &latestVideoUri);
+
+        // Picture
         void imagesDirectoryChanged(const QString &imagesDirectory);
         void imageFormatChanged(const QString &imageFormat);
         void lastPhotoPreviewChanged(const QString &lastPhotoPreview);
+        void latestPhotoUriChanged(const QString &latestPhotoUri);
         void imageSaveQualityChanged(int imageSaveQuality);
 
     public slots:
+        // General options
         void setAudioCaps(const AkAudioCaps &audioCaps);
         void setVideoCaps(const AkVideoCaps &videoCaps);
-        void setState(AkElement::ElementState state);
+        bool setState(AkElement::ElementState state);
+
+        // Video
         void setVideoDirectory(const QString &videoDirectory);
-        void setVideoFormat(const QString &videoFormat);
-        void setVideoFormatExtension(const QString &videoFormatExtension);
-        void setVideoFormatOptions(const QVariantMap &videoFormatOptions);
-        void setVideoCodec(const QString &videoCodec);
-        void setAudioCodec(const QString &audioCodec);
-        void setVideoCodecParams(const QVariantMap &videoCodecParams);
-        void setAudioCodecParams(const QVariantMap &audioCodecParams);
-        void setVideoCodecOptions(const QVariantMap &videoCodecOptions);
-        void setAudioCodecOptions(const QVariantMap &audioCodecOptions);
+        void setVideoFormat(const QString &format);
+        void setCodec(AkCaps::CapsType type, const QString &codec);
+        void setVideoFormatOptionValue(const QString &option,
+                                       const QVariant &value);
+        void setCodecOptionValue(AkCaps::CapsType type,
+                                 const QString &option,
+                                 const QVariant &value);
+        void setBitrate(AkCaps::CapsType type, int bitrate);
+        void setVideoGOP(int gop);
         void setRecordAudio(bool recordAudio);
+
+        // Picture
         void setImagesDirectory(const QString &imagesDirectory);
         void setImageFormat(const QString &imageFormat);
         void setImageSaveQuality(int imageSaveQuality);
+
+        // General options
         void resetAudioCaps();
         void resetVideoCaps();
         void resetState();
+
+        // Video
         void resetVideoDirectory();
         void resetVideoFormat();
-        void resetVideoFormatExtension();
+        void resetCodec(AkCaps::CapsType type);
+        void resetVideoFormatOptionValue(const QString &option);
+        void resetCodecOptionValue(AkCaps::CapsType type,
+                                   const QString &option);
         void resetVideoFormatOptions();
-        void resetVideoCodec();
-        void resetAudioCodec();
-        void resetVideoCodecParams();
-        void resetAudioCodecParams();
-        void resetVideoCodecOptions();
-        void resetAudioCodecOptions();
+        void resetCodecOptions(AkCaps::CapsType type);
+        void resetBitrate(AkCaps::CapsType type);
+        void resetVideoGOP();
         void resetRecordAudio();
+
+        // Picture
         void resetImagesDirectory();
         void resetImageFormat();
         void resetImageSaveQuality();
+
         void takePhoto();
         void savePhoto(const QString &fileName);
-		bool copyToClipboard();
+        bool copyToClipboard();
         AkPacket iStream(const AkPacket &packet);
         void setQmlEngine(QQmlApplicationEngine *engine=nullptr);
 
