@@ -23,9 +23,11 @@
 #include <QQmlEngine>
 
 #include "akvideopacket.h"
+#include "akalgorithm.h"
 #include "akcolorconvert.h"
 #include "akfrac.h"
 #include "akpacket.h"
+#include "aksimd.h"
 #include "akvideoformatspec.h"
 
 #define MAX_PLANES 4
@@ -42,6 +44,7 @@ enum FillDataTypes
     FillDataTypes_8,
     FillDataTypes_16,
     FillDataTypes_32,
+    FillDataTypes_64,
 };
 
 enum AlphaMode
@@ -50,6 +53,8 @@ enum AlphaMode
     AlphaMode_O,
 };
 
+class FillParameters;
+
 class FillParameters
 {
     public:
@@ -104,6 +109,8 @@ class FillParameters
         void reset();
 };
 
+using FillParametersPtr = QSharedPointer<FillParameters>;
+
 class AkVideoPacketPrivate
 {
     public:
@@ -120,73 +127,10 @@ class AkVideoPacketPrivate
         size_t m_widthDiv[MAX_PLANES];
         size_t m_heightDiv[MAX_PLANES];
         size_t m_align {32};
+        FillParametersPtr m_fc;
 
         void updateParams(const AkVideoFormatSpec &specs);
         inline void updatePlanes();
-        template<typename T>
-        static inline T alignUp(const T &value, const T &align)
-        {
-            return (value + align - 1) & ~(align - 1);
-        }
-
-        // Endianness conversion functions for color components
-
-        inline quint8 swapBytes(quint8 &&value, int endianness) const
-        {
-            Q_UNUSED(endianness)
-
-            return value;
-        }
-
-        inline quint16 swapBytes(quint16 &&value, int endianness) const
-        {
-            if (endianness == Q_BYTE_ORDER)
-                return value;
-
-            quint16 result;
-            auto pv = reinterpret_cast<quint8 *>(&value);
-            auto pr = reinterpret_cast<quint8 *>(&result);
-            pr[0] = pv[1];
-            pr[1] = pv[0];
-
-            return result;
-        }
-
-        inline quint32 swapBytes(quint32 &&value, int endianness) const
-        {
-            if (endianness == Q_BYTE_ORDER)
-                return value;
-
-            quint32 result;
-            auto pv = reinterpret_cast<quint8 *>(&value);
-            auto pr = reinterpret_cast<quint8 *>(&result);
-            pr[0] = pv[3];
-            pr[1] = pv[2];
-            pr[2] = pv[1];
-            pr[3] = pv[0];
-
-            return result;
-        }
-
-        inline quint64 swapBytes(quint64 &&value, int endianness) const
-        {
-            if (endianness == Q_BYTE_ORDER)
-                return value;
-
-            quint64 result;
-            auto pv = reinterpret_cast<quint8 *>(&value);
-            auto pr = reinterpret_cast<quint8 *>(&result);
-            pr[0] = pv[7];
-            pr[1] = pv[6];
-            pr[2] = pv[5];
-            pr[3] = pv[4];
-            pr[4] = pv[3];
-            pr[5] = pv[2];
-            pr[6] = pv[1];
-            pr[7] = pv[0];
-
-            return result;
-        }
 
         /* Fill functions */
 
@@ -210,7 +154,7 @@ class AkVideoPacketPrivate
 
             auto width = qMax<size_t>(8 * this->m_pixelSize[0] / this->m_caps.bpp(), 1);
 
-            for (int x = 0; x < width; ++x) {
+            for (size_t x = 0; x < width; ++x) {
                 int &xd_x = fc.dstWidthOffsetX[x];
                 int &xd_y = fc.dstWidthOffsetY[x];
                 int &xd_z = fc.dstWidthOffsetZ[x];
@@ -222,14 +166,6 @@ class AkVideoPacketPrivate
                 *xo = (*xo & DataType(fc.maskXo)) | (DataType(xo_) << fc.xoShift);
                 *yo = (*yo & DataType(fc.maskYo)) | (DataType(yo_) << fc.yoShift);
                 *zo = (*zo & DataType(fc.maskZo)) | (DataType(zo_) << fc.zoShift);
-
-                auto xot = this->swapBytes(DataType(*xo), fc.endianess);
-                auto yot = this->swapBytes(DataType(*yo), fc.endianess);
-                auto zot = this->swapBytes(DataType(*zo), fc.endianess);
-
-                *xo = xot;
-                *yo = yot;
-                *zo = zot;
             }
         }
 
@@ -253,7 +189,7 @@ class AkVideoPacketPrivate
 
             auto width = qMax<size_t>(8 * this->m_pixelSize[0] / this->m_caps.bpp(), 1);
 
-            for (int x = 0; x < width; ++x) {
+            for (size_t x = 0; x < width; ++x) {
                 int &xd_x = fc.dstWidthOffsetX[x];
                 int &xd_y = fc.dstWidthOffsetY[x];
                 int &xd_z = fc.dstWidthOffsetZ[x];
@@ -268,16 +204,6 @@ class AkVideoPacketPrivate
                 *yo = (*yo & DataType(fc.maskYo)) | (DataType(yo_) << fc.yoShift);
                 *zo = (*zo & DataType(fc.maskZo)) | (DataType(zo_) << fc.zoShift);
                 *ao = (*ao & DataType(fc.maskAo)) | (DataType(ai) << fc.aoShift);
-
-                auto xot = this->swapBytes(DataType(*xo), fc.endianess);
-                auto yot = this->swapBytes(DataType(*yo), fc.endianess);
-                auto zot = this->swapBytes(DataType(*zo), fc.endianess);
-                auto aot = this->swapBytes(DataType(*ao), fc.endianess);
-
-                *xo = xot;
-                *yo = yot;
-                *zo = zot;
-                *ao = aot;
             }
         }
 
@@ -296,11 +222,10 @@ class AkVideoPacketPrivate
             auto line_x = this->m_planes[fc.planeXo] + fc.xoOffset;
             auto width = qMax<size_t>(8 * this->m_pixelSize[0] / this->m_caps.bpp(), 1);
 
-            for (int x = 0; x < width; ++x) {
+            for (size_t x = 0; x < width; ++x) {
                 int &xd_x = fc.dstWidthOffsetX[x];
                 auto xo = reinterpret_cast<DataType *>(line_x + xd_x);
                 *xo = (*xo & DataType(fc.maskXo)) | (DataType(xo_) << fc.xoShift);
-                *xo = this->swapBytes(DataType(*xo), fc.endianess);
             }
         }
 
@@ -320,7 +245,7 @@ class AkVideoPacketPrivate
 
             auto width = qMax<size_t>(8 * this->m_pixelSize[0] / this->m_caps.bpp(), 1);
 
-            for (int x = 0; x < width; ++x) {
+            for (size_t x = 0; x < width; ++x) {
                 int &xd_x = fc.dstWidthOffsetX[x];
                 int &xd_a = fc.dstWidthOffsetA[x];
 
@@ -329,12 +254,6 @@ class AkVideoPacketPrivate
 
                 *xo = (*xo & DataType(fc.maskXo)) | (DataType(xo_) << fc.xoShift);
                 *ao = (*ao & DataType(fc.maskAo)) | (DataType(ai) << fc.aoShift);
-
-                auto xot = this->swapBytes(DataType(*xo), fc.endianess);
-                auto aot = this->swapBytes(DataType(*ao), fc.endianess);
-
-                *xo = xot;
-                *ao = aot;
             }
         }
 
@@ -360,7 +279,7 @@ class AkVideoPacketPrivate
 
             auto width = qMax<size_t>(8 * this->m_pixelSize[0] / this->m_caps.bpp(), 1);
 
-            for (int x = 0; x < width; ++x) {
+            for (size_t x = 0; x < width; ++x) {
                 int &xd_x = fc.dstWidthOffsetX[x];
                 int &xd_y = fc.dstWidthOffsetY[x];
                 int &xd_z = fc.dstWidthOffsetZ[x];
@@ -372,14 +291,6 @@ class AkVideoPacketPrivate
                 *xo = (*xo & DataType(fc.maskXo)) | (DataType(xo_) << fc.xoShift);
                 *yo = (*yo & DataType(fc.maskYo)) | (DataType(yo_) << fc.yoShift);
                 *zo = (*zo & DataType(fc.maskZo)) | (DataType(zo_) << fc.zoShift);
-
-                auto xot = this->swapBytes(DataType(*xo), fc.endianess);
-                auto yot = this->swapBytes(DataType(*yo), fc.endianess);
-                auto zot = this->swapBytes(DataType(*zo), fc.endianess);
-
-                *xo = xot;
-                *yo = yot;
-                *zo = zot;
             }
         }
 
@@ -403,7 +314,7 @@ class AkVideoPacketPrivate
 
             auto width = qMax<size_t>(8 * this->m_pixelSize[0] / this->m_caps.bpp(), 1);
 
-            for (int x = 0; x < width; ++x) {
+            for (size_t x = 0; x < width; ++x) {
                 int &xd_x = fc.dstWidthOffsetX[x];
                 int &xd_y = fc.dstWidthOffsetY[x];
                 int &xd_z = fc.dstWidthOffsetZ[x];
@@ -418,16 +329,6 @@ class AkVideoPacketPrivate
                 *yo = (*yo & DataType(fc.maskYo)) | (DataType(yo_) << fc.yoShift);
                 *zo = (*zo & DataType(fc.maskZo)) | (DataType(zo_) << fc.zoShift);
                 *ao = (*ao & DataType(fc.maskAo)) | (DataType(ai) << fc.aoShift);
-
-                auto xot = this->swapBytes(DataType(*xo), fc.endianess);
-                auto yot = this->swapBytes(DataType(*yo), fc.endianess);
-                auto zot = this->swapBytes(DataType(*zo), fc.endianess);
-                auto aot = this->swapBytes(DataType(*ao), fc.endianess);
-
-                *xo = xot;
-                *yo = yot;
-                *zo = zot;
-                *ao = aot;
             }
         }
 
@@ -488,22 +389,22 @@ AkVideoPacket::AkVideoPacket(QObject *parent):
     AkPacketBase(parent)
 {
     this->d = new AkVideoPacketPrivate;
+    this->d->m_align = AkSimd::preferredAlign();
 }
 
-AkVideoPacket::AkVideoPacket(const AkVideoCaps &caps,
-                             bool initialized,
-                             size_t align):
+AkVideoPacket::AkVideoPacket(const AkVideoCaps &caps, bool initialized):
     AkPacketBase()
 {
     this->d = new AkVideoPacketPrivate;
     this->d->m_caps = caps;
-    this->d->m_align = align;
+    this->d->m_align = AkSimd::preferredAlign();
     auto specs = AkVideoCaps::formatSpecs(this->d->m_caps.format());
     this->d->m_nPlanes = specs.planes();
     this->d->updateParams(specs);
 
     if (this->d->m_dataSize > 0) {
-            this->d->m_data = new quint8 [this->d->m_dataSize];
+            this->d->m_data =
+                    AkSimd::amallocT<quint8>(this->d->m_dataSize, this->d->m_align);
 
             if (initialized)
                 memset(this->d->m_data, 0, this->d->m_dataSize);
@@ -522,7 +423,8 @@ AkVideoPacket::AkVideoPacket(const AkPacket &other):
         this->d->m_caps = data->d->m_caps;
 
         if (data->d->m_data && data->d->m_dataSize > 0) {
-                this->d->m_data = new quint8 [data->d->m_dataSize];
+                this->d->m_data =
+                        AkSimd::amallocT<quint8>(data->d->m_dataSize, data->d->m_align);
                 memcpy(this->d->m_data, data->d->m_data, data->d->m_dataSize);
         }
 
@@ -541,6 +443,7 @@ AkVideoPacket::AkVideoPacket(const AkPacket &other):
         }
 
         this->d->m_align = data->d->m_align;
+        this->d->m_fc = data->d->m_fc;
         this->d->updatePlanes();
     }
 }
@@ -552,7 +455,8 @@ AkVideoPacket::AkVideoPacket(const AkVideoPacket &other):
     this->d->m_caps = other.d->m_caps;
 
     if (other.d->m_data && other.d->m_dataSize > 0) {
-        this->d->m_data = new quint8 [other.d->m_dataSize];
+        this->d->m_data =
+                AkSimd::amallocT<quint8>(other.d->m_dataSize, other.d->m_align);
         memcpy(this->d->m_data, other.d->m_data, other.d->m_dataSize);
     }
 
@@ -571,13 +475,14 @@ AkVideoPacket::AkVideoPacket(const AkVideoPacket &other):
     }
 
     this->d->m_align = other.d->m_align;
+    this->d->m_fc = other.d->m_fc;
     this->d->updatePlanes();
 }
 
 AkVideoPacket::~AkVideoPacket()
 {
     if (this->d->m_data)
-        delete [] this->d->m_data;
+        AkSimd::afree(this->d->m_data);
 
     delete this->d;
 }
@@ -589,12 +494,13 @@ AkVideoPacket &AkVideoPacket::operator =(const AkPacket &other)
         this->d->m_caps = data->d->m_caps;
 
         if (this->d->m_data) {
-            delete [] this->d->m_data;
+            AkSimd::afree(this->d->m_data);
             this->d->m_data = nullptr;
         }
 
         if (data->d->m_data && data->d->m_dataSize > 0) {
-            this->d->m_data = new quint8 [data->d->m_dataSize];
+            this->d->m_data =
+                    AkSimd::amallocT<quint8>(data->d->m_dataSize, data->d->m_align);
             memcpy(this->d->m_data, data->d->m_data, data->d->m_dataSize);
         }
 
@@ -613,18 +519,19 @@ AkVideoPacket &AkVideoPacket::operator =(const AkPacket &other)
         }
 
         this->d->m_align = data->d->m_align;
+        this->d->m_fc = data->d->m_fc;
         this->d->updatePlanes();
     } else {
         this->d->m_caps = AkVideoCaps();
 
         if (this->d->m_data) {
-            delete [] this->d->m_data;
+            AkSimd::afree(this->d->m_data);
             this->d->m_data = nullptr;
         }
 
         this->d->m_dataSize = 0;
         this->d->m_nPlanes = 0;
-        this->d->m_align = 32;
+        this->d->m_align = AkSimd::preferredAlign();
     }
 
     this->copyMetadata(other);
@@ -638,12 +545,13 @@ AkVideoPacket &AkVideoPacket::operator =(const AkVideoPacket &other)
         this->d->m_caps = other.d->m_caps;
 
         if (this->d->m_data) {
-            delete [] this->d->m_data;
+            AkSimd::afree(this->d->m_data);
             this->d->m_data = nullptr;
         }
 
         if (other.d->m_data && other.d->m_dataSize > 0) {
-            this->d->m_data = new quint8 [other.d->m_dataSize];
+            this->d->m_data =
+                    AkSimd::amallocT<quint8>(other.d->m_dataSize, other.d->m_align);
             memcpy(this->d->m_data, other.d->m_data, other.d->m_dataSize);
         }
 
@@ -662,6 +570,7 @@ AkVideoPacket &AkVideoPacket::operator =(const AkVideoPacket &other)
 
         this->copyMetadata(other);
         this->d->m_align = other.d->m_align;
+        this->d->m_fc = other.d->m_fc;
         this->d->updatePlanes();
     }
 
@@ -840,6 +749,11 @@ QDebug operator <<(QDebug debug, const AkVideoPacket &packet)
                     << "("
                     << packet.pts() * packet.timeBase().value()
                     << ")"
+                    << ",duration="
+                    << packet.duration()
+                    << "("
+                    << packet.duration() * packet.timeBase().value()
+                    << ")"
                     << ",timeBase="
                     << packet.timeBase()
                     << ",index="
@@ -851,34 +765,46 @@ QDebug operator <<(QDebug debug, const AkVideoPacket &packet)
 
 void AkVideoPacketPrivate::updateParams(const AkVideoFormatSpec &specs)
 {
-    if (this->m_align < 1)
-        this->m_align = 32;
-
     this->m_dataSize = 0;
-    int i = 0;
 
-    for (size_t j = 0; j < specs.planes(); ++j) {
-        auto &plane = specs.plane(j);
+    // Calculate parameters for each plane
+    for (size_t i = 0; i < specs.planes(); ++i) {
+        auto &plane = specs.plane(i);
+
+        // Calculate bytes used per line (bits per pixel * width / 8)
         size_t bytesUsed = plane.bitsSize() * this->m_caps.width() / 8;
-        size_t lineSize =
-                AkVideoPacketPrivate::alignUp(bytesUsed, size_t(this->m_align));
 
+        // Align line size for SIMD compatibility
+        size_t lineSize =
+                AkAlgorithm::alignUp(bytesUsed, size_t(this->m_align));
+
+        // Store pixel size, line size, and bytes used
         this->m_pixelSize[i] = plane.pixelSize();
         this->m_lineSize[i] = lineSize;
         this->m_bytesUsed[i] = bytesUsed;
 
+        // Calculate plane size, considering sub-sampling
         size_t planeSize = (lineSize * this->m_caps.height()) >> plane.heightDiv();
 
+        // Align plane size to ensure next plane starts aligned
+        planeSize =
+                AkAlgorithm::alignUp(planeSize, size_t(this->m_align));
+
+        // Store plane size and offset
         this->m_planeSize[i] = planeSize;
         this->m_planeOffset[i] = this->m_dataSize;
 
+        // Update total data size
         this->m_dataSize += planeSize;
 
+        // Store width and height divisors for sub-sampling
         this->m_widthDiv[i] = plane.widthDiv();
         this->m_heightDiv[i] = plane.heightDiv();
-
-        i++;
     }
+
+    // Align total data size for buffer allocation
+    this->m_dataSize =
+            AkAlgorithm::alignUp(this->m_dataSize, size_t(this->m_align));
 }
 
 void AkVideoPacketPrivate::updatePlanes()
@@ -888,20 +814,30 @@ void AkVideoPacketPrivate::updatePlanes()
 }
 
 #define DEFINE_FILL_FUNC(size) \
-case FillDataTypes_##size: \
-    this->fill<quint##size>(fc, color); \
-    break;
+    case FillDataTypes_##size: \
+        this->fill<quint##size>(*this->m_fc, color); \
+        \
+        if (this->m_fc->endianess != Q_BYTE_ORDER) \
+            for (size_t plane = 0; plane < this->m_nPlanes; ++plane) \
+                AkAlgorithm::swapDataBytes(reinterpret_cast<quint##size *>(this->m_planes[plane]), this->m_pixelSize[plane]); \
+        \
+        break;
 
 void AkVideoPacketPrivate::fill(QRgb color)
 {
-    FillParameters fc;
-    fc.configure(this->m_caps, fc.colorConvert);
-    fc.configureFill(this->m_caps);
+    if (!this->m_fc) {
+        this->m_fc = FillParametersPtr(new FillParameters);
+        this->m_fc->configure(this->m_caps, this->m_fc->colorConvert);
+        this->m_fc->configureFill(this->m_caps);
+    }
 
-    switch (fc.fillDataTypes) {
-        DEFINE_FILL_FUNC(8)
-        DEFINE_FILL_FUNC(16)
-        DEFINE_FILL_FUNC(32)
+    switch (this->m_fc->fillDataTypes) {
+    DEFINE_FILL_FUNC(8)
+    DEFINE_FILL_FUNC(16)
+    DEFINE_FILL_FUNC(32)
+    DEFINE_FILL_FUNC(64)
+    default:
+        break;
     }
 
     for (size_t plane = 0; plane < this->m_nPlanes; plane++) {
@@ -910,7 +846,7 @@ void AkVideoPacketPrivate::fill(QRgb color)
         auto line0 = this->m_planes[plane];
         auto line = line0 + pixelSize;
         auto width = lineSize / pixelSize;
-        auto height = fc.height >> this->m_heightDiv[plane];
+        auto height = this->m_fc->height >> this->m_heightDiv[plane];
 
         for (int x = 1; x < width; ++x) {
             memcpy(line, line0, pixelSize);
@@ -1084,7 +1020,7 @@ void FillParameters::allocateBuffers(const AkVideoCaps &caps)
 }
 
 #define DEFINE_FILL_TYPES(size) \
-    if (ospecs.byteLength() == (size / 8)) \
+    if (ospecs.depth() == size) \
         this->fillDataTypes = FillDataTypes_##size;
 
 void FillParameters::configure(const AkVideoCaps &caps,
@@ -1096,6 +1032,7 @@ void FillParameters::configure(const AkVideoCaps &caps,
     DEFINE_FILL_TYPES(8);
     DEFINE_FILL_TYPES(16);
     DEFINE_FILL_TYPES(32);
+    DEFINE_FILL_TYPES(64);
 
     auto components = ospecs.mainComponents();
 
