@@ -57,9 +57,12 @@ inline AkYuv akYuv(int y, int u, int v)
     return akYuv(y, v, u, 255);
 }
 
+class AkVideoPacket;
 class AkVideoPacketPrivate;
 class AkPacket;
 
+using AkVideoPackets = QVector<AkVideoPacket>;
+
 class AKCOMMONS_EXPORT AkVideoPacket: public AkPacketBase
 {
     Q_OBJECT
@@ -75,9 +78,7 @@ class AKCOMMONS_EXPORT AkVideoPacket: public AkPacketBase
 
     public:
         AkVideoPacket(QObject *parent=nullptr);
-        AkVideoPacket(const AkVideoCaps &caps,
-                      bool initialized=false,
-                      size_t align=32);
+        AkVideoPacket(const AkVideoCaps &caps, bool initialized=false);
         AkVideoPacket(const AkPacket &other);
         AkVideoPacket(const AkVideoPacket &other);
         ~AkVideoPacket();
