@@ -17,6 +17,7 @@
  * Web-Site: http://webcamoid.github.io/
  */
 
+#include <QAbstractEventDispatcher>
 #include <QCoreApplication>
 #include <QMap>
 #include <QVector>
@@ -368,6 +369,11 @@ class AudioDevJNIAudioPrivate
         int m_bufferSize {0};
         bool m_hasAudioCapturePermissions {false};
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+        QMicrophonePermission m_microphonePermission;
+        bool m_permissionResultReady {false};
+#endif
+
         explicit AudioDevJNIAudioPrivate(AudioDevJNIAudio *self);
         void registerNatives();
         QJniObject deviceInfo(const QString &device);
@@ -384,30 +390,37 @@ AudioDevJNIAudio::AudioDevJNIAudio(QObject *parent):
     this->d = new AudioDevJNIAudioPrivate(this);
 
 #if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
-    QMicrophonePermission microphonePermission;
+    auto permissionStatus =
+            qApp->checkPermission(this->d->m_microphonePermission);
 
-    switch (qApp->checkPermission(microphonePermission)) {
-    case Qt::PermissionStatus::Granted:
+    if (permissionStatus == Qt::PermissionStatus::Granted) {
+        qInfo() << "Permission granted for audio capture with Android JNI API";
         this->d->m_hasAudioCapturePermissions = true;
-        this->d->updateDevices();
-
-        break;
-
-    default:
-        qApp->requestPermission(microphonePermission,
+    } else {
+        this->d->m_permissionResultReady = false;
+        qApp->requestPermission(this->d->m_microphonePermission,
                                 this,
                                 [this] (const QPermission &permission) {
-                                    if (permission.status() == Qt::PermissionStatus::Granted)
+                                    if (permission.status() == Qt::PermissionStatus::Granted) {
+                                        qInfo() << "Permission granted for audio capture with Android JNI API";
                                         this->d->m_hasAudioCapturePermissions = true;
+                                    } else {
+                                        qWarning() << "Permission denied for audio capture with Android JNI API";
+                                    }
 
-                                    this->d->updateDevices();
+                                    this->d->m_permissionResultReady = true;
                                 });
 
-        break;
+        while (!this->d->m_permissionResultReady) {
+            auto eventDispatcher = QThread::currentThread()->eventDispatcher();
+
+            if (eventDispatcher)
+                eventDispatcher->processEvents(QEventLoop::AllEvents);
+        }
     }
-#else
-    this->d->updateDevices();
 #endif
+
+    this->d->updateDevices();
 }
 
 AudioDevJNIAudio::~AudioDevJNIAudio()
@@ -473,6 +486,12 @@ bool AudioDevJNIAudio::init(const QString &device, const AkAudioCaps &caps)
             qMax(this->latency() * caps.rate() / 1000, 1)
                  * AkAudioCaps::bitsPerSample(caps.format())
                  * caps.channels() / 8;
+
+    qInfo() << "Initializing the audio device with JNI";
+    qInfo() << "    Device:" << device;
+    qInfo() << "    Caps:" << this->d->m_curCaps;
+    qInfo() << "    Buffer size:" << this->d->m_bufferSize;
+
     return device.startsWith("OutputDevice_")?
                 this->d->initPlayer(device, caps):
                 this->d->initRecorder(device, caps);
@@ -599,11 +618,13 @@ void AudioDevJNIAudioPrivate::registerNatives()
     QJniEnvironment jniEnv;
 
     if (auto jclass = jniEnv.findClass(JCLASS(AkAndroidAudioCallbacks))) {
-        static const QVector<JNINativeMethod> methods {
+        static const QVector<JNINativeMethod> androidJniAudioMethods {
             {"devicesUpdated", "(J)V", reinterpret_cast<void *>(AudioDevJNIAudioPrivate::devicesUpdated)},
         };
 
-        jniEnv->RegisterNatives(jclass, methods.data(), methods.size());
+        jniEnv->RegisterNatives(jclass,
+                                androidJniAudioMethods.data(),
+                                androidJniAudioMethods.size());
     }
 
     ready = true;
@@ -646,10 +667,15 @@ QJniObject AudioDevJNIAudioPrivate::deviceInfo(const QString &device)
 bool AudioDevJNIAudioPrivate::initPlayer(const QString &device,
                                          const AkAudioCaps &caps)
 {
+    qInfo() << "Starting audio playback";
+
     jint encoding = sampleFormatsMap->key(caps.format(), ENCODING_INVALID);
 
-    if (encoding == ENCODING_INVALID)
+    if (encoding == ENCODING_INVALID) {
+        qCritical() << "An equivalent sample format was not found for" << caps.format();
+
         return false;
+    }
 
     jint channelMask =
             caps.layout() == AkAudioCaps::Layout_mono?
@@ -658,20 +684,29 @@ bool AudioDevJNIAudioPrivate::initPlayer(const QString &device,
                 CHANNEL_OUT_STEREO:
                 0;
 
-    if (channelMask == 0)
+    if (channelMask == 0) {
+        qCritical() << "Invalid channel layout: " << caps.layout();
+
         return false;
+    }
 
     jint sampleRate = caps.rate();
 
-    if (sampleRate < 1)
+    if (sampleRate < 1) {
+        qCritical() << "Invalid sample rate: " << caps.rate();
+
         return false;
+    }
 
     // Get device info
 
     auto deviceInfo = this->deviceInfo(device);
 
-    if (!deviceInfo.isValid())
+    if (!deviceInfo.isValid()){
+        qCritical() << "Can't read the device info";
+
         return false;
+    }
 
     auto apiLevel = android_get_device_api_level();
 
@@ -762,8 +797,11 @@ bool AudioDevJNIAudioPrivate::initPlayer(const QString &device,
             trackBuilder.callObjectMethod("build",
                                           "()Landroid/media/AudioTrack;");
 
-    if (!this->m_player.isValid())
+    if (!this->m_player.isValid()) {
+        qCritical() << "Can't build AudioTrack";
+
         return false;
+    }
 
     this->m_player.callMethod<jboolean>("setPreferredDevice",
                                         "(Landroid/media/AudioDeviceInfo;)Z",
@@ -777,10 +815,15 @@ bool AudioDevJNIAudioPrivate::initPlayer(const QString &device,
 bool AudioDevJNIAudioPrivate::initRecorder(const QString &device,
                                            const AkAudioCaps &caps)
 {
+    qInfo() << "Starting audio recording";
+
     jint encoding = sampleFormatsMap->key(caps.format(), ENCODING_INVALID);
 
-    if (encoding == ENCODING_INVALID)
+    if (encoding == ENCODING_INVALID){
+        qCritical() << "An equivalent sample format was not found for" << caps.format();
+
         return false;
+    }
 
     jint channelMask =
             caps.layout() == AkAudioCaps::Layout_mono?
@@ -789,20 +832,29 @@ bool AudioDevJNIAudioPrivate::initRecorder(const QString &device,
                 CHANNEL_IN_STEREO:
                 0;
 
-    if (channelMask == 0)
+    if (channelMask == 0){
+        qCritical() << "Invalid channel layout: " << caps.layout();
+
         return false;
+    }
 
     jint sampleRate = caps.rate();
 
-    if (sampleRate < 1)
+    if (sampleRate < 1) {
+        qCritical() << "Invalid sample rate: " << caps.rate();
+
         return false;
+    }
 
     // Get device info
 
     auto deviceInfo = this->deviceInfo(device);
 
-    if (!deviceInfo.isValid())
+    if (!deviceInfo.isValid()) {
+        qCritical() << "Can't read the device info";
+
         return false;
+    }
 
     // Configure format
 
@@ -857,8 +909,11 @@ bool AudioDevJNIAudioPrivate::initRecorder(const QString &device,
             recordBuilder.callObjectMethod("build",
                                            "()Landroid/media/AudioRecord;");
 
-    if (!this->m_recorder.isValid())
+    if (!this->m_recorder.isValid()) {
+        qCritical() << "Can't build AudioRecord";
+
         return false;
+    }
 
     this->m_recorder.callMethod<jboolean>("setPreferredDevice",
                                           "(Landroid/media/AudioDeviceInfo;)Z",
