@@ -19,24 +19,10 @@
 
 #include "audiodevice.h"
 #include "audiodeviceelement.h"
-#include "audiodeviceelementsettings.h"
 
-QObject *AudioDevice::create(const QString &key, const QString &specification)
+QObject *AudioDevice::create()
 {
-    Q_UNUSED(specification)
-
-    if (key == AK_PLUGIN_TYPE_ELEMENT)
-        return new AudioDeviceElement();
-    else if (key == AK_PLUGIN_TYPE_ELEMENT_SETTINGS)
-        return new AudioDeviceElementSettings();
-
-    return nullptr;
-}
-
-QStringList AudioDevice::keys() const
-{
-    return {AK_PLUGIN_TYPE_ELEMENT,
-            AK_PLUGIN_TYPE_ELEMENT_SETTINGS};
+    return new AudioDeviceElement();
 }
 
 #include "moc_audiodevice.cpp"
