@@ -20,19 +20,9 @@
 #include "blur.h"
 #include "blurelement.h"
 
-QObject *Blur::create(const QString &key, const QString &specification)
+QObject *Blur::create()
 {
-    Q_UNUSED(specification)
-
-    if (key == AK_PLUGIN_TYPE_ELEMENT)
-        return new BlurElement();
-
-    return nullptr;
-}
-
-QStringList Blur::keys() const
-{
-    return QStringList();
+    return new BlurElement();
 }
 
 #include "moc_blur.cpp"
