@@ -20,17 +20,16 @@
 #ifndef BLUR_H
 #define BLUR_H
 
-#include <akplugin.h>
+#include <iak/akplugin.h>
 
 class Blur: public QObject, public AkPlugin
 {
     Q_OBJECT
     Q_INTERFACES(AkPlugin)
-    Q_PLUGIN_METADATA(IID "org.avkys.plugin" FILE "pspec.json")
+    Q_PLUGIN_METADATA(IID AkPlugin_IID FILE "pspec.json")
 
     public:
-        QObject *create(const QString &key, const QString &specification);
-        QStringList keys() const;
+        QObject *create() override;
 };
 
 #endif // BLUR_H
