@@ -21,7 +21,7 @@
 #define CHARIFYELEMENT_H
 
 #include <qrgb.h>
-#include <akelement.h>
+#include <iak/akelement.h>
 
 class CharifyElementPrivate;
 
