@@ -20,19 +20,9 @@
 #include "cinema.h"
 #include "cinemaelement.h"
 
-QObject *Cinema::create(const QString &key, const QString &specification)
+QObject *Cinema::create()
 {
-    Q_UNUSED(specification)
-
-    if (key == AK_PLUGIN_TYPE_ELEMENT)
-        return new CinemaElement();
-
-    return nullptr;
-}
-
-QStringList Cinema::keys() const
-{
-    return QStringList();
+    return new CinemaElement();
 }
 
 #include "moc_cinema.cpp"
