@@ -20,7 +20,7 @@
 #ifndef DENOISEELEMENT_H
 #define DENOISEELEMENT_H
 
-#include <akelement.h>
+#include <iak/akelement.h>
 
 class DenoiseElementPrivate;
 
@@ -61,10 +61,10 @@ class DenoiseElement: public AkElement
         DenoiseElementPrivate *d;
 
     protected:
-        QString controlInterfaceProvide(const QString &controlId) const;
+        QString controlInterfaceProvide(const QString &controlId) const override;
         void controlInterfaceConfigure(QQmlContext *context,
-                                       const QString &controlId) const;
-        AkPacket iVideoStream(const AkVideoPacket &packet);
+                                       const QString &controlId) const override;
+        AkPacket iVideoStream(const AkVideoPacket &packet) override;
 
     signals:
         void radiusChanged(int radius);
