@@ -46,6 +46,22 @@ class PipewireScreenDev: public ScreenDev
                WRITE setFps
                RESET resetFps
                NOTIFY fpsChanged)
+    Q_PROPERTY(bool canCaptureCursor
+               READ canCaptureCursor
+               CONSTANT)
+    Q_PROPERTY(bool canChangeCursorSize
+               READ canChangeCursorSize
+               CONSTANT)
+    Q_PROPERTY(bool showCursor
+               READ showCursor
+               WRITE setShowCursor
+               RESET resetShowCursor
+               NOTIFY showCursorChanged)
+    Q_PROPERTY(int cursorSize
+               READ cursorSize
+               WRITE setCursorSize
+               RESET resetCursorSize
+               NOTIFY cursorSizeChanged)
 
     public:
         PipewireScreenDev();
@@ -58,6 +74,10 @@ class PipewireScreenDev: public ScreenDev
         Q_INVOKABLE int defaultStream(AkCaps::CapsType type) override;
         Q_INVOKABLE QString description(const QString &media) override;
         Q_INVOKABLE AkVideoCaps caps(int stream) override;
+        Q_INVOKABLE bool canCaptureCursor() const override;
+        Q_INVOKABLE bool canChangeCursorSize() const override;
+        Q_INVOKABLE bool showCursor() const override;
+        Q_INVOKABLE int cursorSize() const override;
 
     private:
         PipewireScreenDevPrivate *d;
@@ -69,15 +89,21 @@ class PipewireScreenDev: public ScreenDev
         void loopChanged(bool loop);
         void fpsChanged(const AkFrac &fps);
         void sizeChanged(const QString &media, const QSize &size);
+        void showCursorChanged(bool showCursor);
+        void cursorSizeChanged(int cursorSize);
         void error(const QString &message);
 
     public slots:
         void setFps(const AkFrac &fps) override;
         void resetFps() override;
         void setMedia(const QString &media) override;
+        void setShowCursor(bool showCursor) override;
+        void setCursorSize(int cursorSize) override;
         void resetMedia() override;
         void setStreams(const QList<int> &streams) override;
         void resetStreams() override;
+        void resetShowCursor() override;
+        void resetCursorSize() override;
         bool init() override;
         bool uninit() override;
 
