@@ -17,20 +17,27 @@
  * Web-Site: http://webcamoid.github.io/
  */
 
+#include <QGuiApplication>
+#include <QLibrary>
+
 #include "plugin.h"
 #include "pipewirescreendev.h"
 
-QObject *Plugin::create(const QString &key, const QString &specification)
+bool Plugin::canLoad()
 {
-    Q_UNUSED(key)
-    Q_UNUSED(specification)
+    if (qApp->platformName() != "wayland")
+        return false;
 
+#ifdef USE_PIPEWIRE_DYNLOAD
+    return QLibrary("pipewire-0.3").load();
+#else
+    return true;
+#endif
+}
+
+QObject *Plugin::create()
+{
     return new PipewireScreenDev();
 }
 
-QStringList Plugin::keys() const
-{
-    return {};
-}
-
 #include "moc_plugin.cpp"
