@@ -17,20 +17,35 @@
  * Web-Site: http://webcamoid.github.io/
  */
 
+#include <QGuiApplication>
+
 #include "plugin.h"
 #include "xlibdev.h"
 
-QObject *Plugin::create(const QString &key, const QString &specification)
-{
-    Q_UNUSED(key)
-    Q_UNUSED(specification)
+#ifdef Q_OS_UNIX
+#include <X11/Xlib.h>
+#endif
 
+bool Plugin::canLoad()
+{
+    if (qApp->platformName() == "wayland")
+        return false;
+
+#ifdef Q_OS_UNIX
+    auto display = XOpenDisplay(nullptr);
+
+     if (!display)
+         return false;
+
+    XCloseDisplay(display);
+#endif
+
+    return true;
+}
+
+QObject *Plugin::create()
+{
     return new XlibDev();
 }
 
-QStringList Plugin::keys() const
-{
-    return {};
-}
-
 #include "moc_plugin.cpp"
