@@ -20,7 +20,9 @@
 #ifndef EQUALIZEELEMENT_H
 #define EQUALIZEELEMENT_H
 
-#include <akelement.h>
+#include <iak/akelement.h>
+
+class EqualizeElementPrivate;
 
 class EqualizeElement: public AkElement
 {
@@ -28,9 +30,13 @@ class EqualizeElement: public AkElement
 
     public:
         EqualizeElement();
+        ~EqualizeElement();
+
+    private:
+        EqualizeElementPrivate *d;
 
     protected:
-        AkPacket iVideoStream(const AkVideoPacket &packet);
+        AkPacket iVideoStream(const AkVideoPacket &packet) override;
 };
 
 #endif // EQUALIZEELEMENT_H
