@@ -21,7 +21,7 @@
 #define FACEDETECTELEMENT_H
 
 #include <qrgb.h>
-#include <akelement.h>
+#include <iak/akelement.h>
 
 class FaceDetectElementPrivate;
 
