@@ -20,7 +20,7 @@
 #ifndef FLIPELEMENT_H
 #define FLIPELEMENT_H
 
-#include <akelement.h>
+#include <iak/akelement.h>
 
 class FlipElementPrivate;
 
