@@ -20,17 +20,9 @@
 #include "frameoverlap.h"
 #include "frameoverlapelement.h"
 
-QObject *FrameOverlap::create(const QString &key, const QString &specification)
+QObject *FrameOverlap::create()
 {
-    Q_UNUSED(key)
-    Q_UNUSED(specification)
-
     return new FrameOverlapElement();
 }
 
-QStringList FrameOverlap::keys() const
-{
-    return {};
-}
-
 #include "moc_frameoverlap.cpp"
