@@ -22,19 +22,12 @@
 #include "hypnotic.h"
 #include "hypnoticelement.h"
 
-QObject *Hypnotic::create(const QString &key, const QString &specification)
+QObject *Hypnotic::create()
 {
-    Q_UNUSED(key)
-    Q_UNUSED(specification)
     qRegisterMetaType<HypnoticElement::OpticMode>("HypnoticOpticMode");
     qmlRegisterType<HypnoticElement>("HypnoticElement", 1, 0, "HypnoticElement");
 
     return new HypnoticElement();
 }
 
-QStringList Hypnotic::keys() const
-{
-    return {};
-}
-
 #include "moc_hypnotic.cpp"
