@@ -21,7 +21,7 @@
 #define MATRIXELEMENT_H
 
 #include <qrgb.h>
-#include <akelement.h>
+#include <iak/akelement.h>
 
 class MatrixElementPrivate;
 
