@@ -37,11 +37,12 @@ class VideoStream: public AbstractStream
                     QObject *parent=nullptr);
         ~VideoStream();
 
-        Q_INVOKABLE AkCaps caps() const;
-        Q_INVOKABLE bool decodeData();
+        Q_INVOKABLE AkCaps caps() const override;
+        Q_INVOKABLE bool eos() const override;
+        Q_INVOKABLE EnqueueResult decodeData() override;
 
     protected:
-        void processData(const AkPacket &packet);
+        void processData(const AkPacket &packet) override;
 
     private:
         VideoStreamPrivate *d;
