@@ -20,17 +20,16 @@
 #ifndef ROTATE_H
 #define ROTATE_H
 
-#include <akplugin.h>
+#include <iak/akplugin.h>
 
 class Rotate: public QObject, public AkPlugin
 {
     Q_OBJECT
     Q_INTERFACES(AkPlugin)
-    Q_PLUGIN_METADATA(IID "org.avkys.plugin" FILE "pspec.json")
+    Q_PLUGIN_METADATA(IID AkPlugin_IID FILE "pspec.json")
 
     public:
-        QObject *create(const QString &key, const QString &specification) override;
-        QStringList keys() const override;
+        QObject *create() override;
 };
 
 #endif // ROTATE_H
