@@ -20,17 +20,9 @@
 #include "swirl.h"
 #include "swirlelement.h"
 
-QObject *Swirl::create(const QString &key, const QString &specification)
+QObject *Swirl::create()
 {
-    Q_UNUSED(key)
-    Q_UNUSED(specification)
-
     return new SwirlElement();
 }
 
-QStringList Swirl::keys() const
-{
-    return {};
-}
-
 #include "moc_swirl.cpp"
