@@ -17,20 +17,23 @@
  * Web-Site: http://webcamoid.github.io/
  */
 
+#include <QLibrary>
+
 #include "plugin.h"
 #include "capturepipewire.h"
 
-QObject *Plugin::create(const QString &key, const QString &specification)
+bool Plugin::canLoad()
 {
-    Q_UNUSED(key)
-    Q_UNUSED(specification)
+#ifdef USE_PIPEWIRE_DYNLOAD
+    return QLibrary("pipewire-0.3").load();
+#else
+    return true;
+#endif
+}
 
+QObject *Plugin::create()
+{
     return new CapturePipeWire();
 }
 
-QStringList Plugin::keys() const
-{
-    return {};
-}
-
 #include "moc_plugin.cpp"
