@@ -21,7 +21,7 @@
 #define VIGNETTEELEMENT_H
 
 #include <qrgb.h>
-#include <akelement.h>
+#include <iak/akelement.h>
 
 class VignetteElementPrivate;
 
