@@ -144,7 +144,7 @@ QString VirtualCameraElement::media() const
 
 QList<int> VirtualCameraElement::streams() const
 {
-    return QList<int> {0};
+    return {0};
 }
 
 int VirtualCameraElement::maxCameras() const
@@ -530,6 +530,18 @@ bool VirtualCameraElement::canEditVCamDescription() const
     return false;
 }
 
+bool VirtualCameraElement::isPassThrough() const
+{
+    this->d->m_mutex.lock();
+    auto vcam = this->d->m_vcam;
+    this->d->m_mutex.unlock();
+
+    if (vcam)
+        return vcam->isPassThrough();
+
+    return false;
+}
+
 QString VirtualCameraElement::controlInterfaceProvide(const QString &controlId) const
 {
     Q_UNUSED(controlId)
